// The Application class for XaoS on BeOS.
// Copyright  1997  Jens Kilian (jjk@acm.org)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <Alert.h>
#include <Application.h>
#include <Bitmap.h>
#include <Message.h>
#include <Point.h>
#include <Rect.h>
#include <ResourceFile.h>
#include <Window.h>

#include "XaoSApplication.h"
#include "XaoSSplashView.h"
#include "XaoSSplashWindow.h"

#include "version.h"

XaoSApplication::XaoSApplication(void)
:	BApplication('XaoS'),
	mpSplashWindow(0)
{
	BBitmap *pSplashBitmap = MakeSplashBitmap();
	if (pSplashBitmap) {
		mpSplashWindow =
			new XaoSSplashWindow(new XaoSSplashView(pSplashBitmap));
	}
}

XaoSApplication::~XaoSApplication(void)
{
	// empty
}

void XaoSApplication::AboutRequested(void)
{
	if (mpSplashWindow) {
		mpSplashWindow->Show();

	} else {
		(new BAlert("About XaoS " XaoS_VERSION,
						"XaoS " XaoS_VERSION "\n"
						"Copyright  1996,1997  Jan Hubicka, Thomas Marsh\n"
						"BeOS driver by Jens Kilian <jjk@acm.org>",
						"OK"))->Go();
	}
}

bool XaoSApplication::QuitRequested(void)
{
	// The splash window must be killed the hard way.
	if (mpSplashWindow) {
		mpSplashWindow->Quit();
		mpSplashWindow = 0;
	}
	return BApplication::QuitRequested();
}

long XaoSApplication::Main(void *data)
{
	((XaoSApplication *)data)->Run();
	return 0;
}

BBitmap *XaoSApplication::MakeSplashBitmap(void)
{
	app_info info;
	if (GetAppInfo(&info) != B_NO_ERROR) {
		return 0;
	}
	
	BResourceFile file(info.ref);
	if (file.Open(B_READ_ONLY) != B_NO_ERROR) {
		return 0;
	}
	
	long length;
	struct splash {
		long width;
		long height;
		char data[1];
	} *pResource =
		(struct splash *)file.FindResource('XaSp', 1, &length);
	file.Close();
	if (!pResource) {
		return 0;
	}
	
	BRect bounds(B_ORIGIN,
					 BPoint(pResource->width-1, pResource->height-1));
	BBitmap *pSplashBitmap = new BBitmap(bounds, B_COLOR_8_BIT);
	pSplashBitmap->SetBits(pResource->data,
								  pResource->width * pResource->height,
								  0,
								  B_COLOR_8_BIT);
	delete pResource;
	
	return pSplashBitmap;
}
