// The Window class for XaoS on BeOS.
// Copyright  1997  Jens Kilian (jjk@acm.org)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <Point.h>
#include <Rect.h>
#include <View.h>
#include <Window.h>

#include "XaoSWindow.h"

#include "version.h"

const BPoint cDefaultLocation(100, 100);

static BRect calcFrame(BRect viewBounds)
{
	viewBounds.OffsetBy(cDefaultLocation);
	return viewBounds;
}

XaoSWindow::XaoSWindow(BView *const pView)
:	BWindow(calcFrame(pView->Bounds()),
			"XaoS " XaoS_VERSION,
			B_TITLED_WINDOW,
			B_NOT_RESIZABLE|B_NOT_ZOOMABLE),	// ARRGH. Should be 0.
	mpView(pView),
	mQuitAllowed(FALSE)
{
	// Attach the view.
	Lock();
	AddChild(mpView);
	Unlock();
}

XaoSWindow::~XaoSWindow(void)
{
	// empty
}

bool XaoSWindow::QuitRequested(void)
{
	// Are we allowed to quit?
	if (!mQuitAllowed) {
		// Not yet ...
		mpView->KeyDown('q');
		
	} else {
		// Yep!
		be_app->PostMessage(B_QUIT_REQUESTED);
	}
	
	return mQuitAllowed;
}

void XaoSWindow::AllowQuit()
{
	// Allow quitting; called from the main thread just before
	// it posts B_QUIT_REQUESTED.
	mQuitAllowed = TRUE;
}
